/* MERG Content-to-template merger
   Command line:
      MERG [switches] template content1 content2 ...

   Valid switches:
      h        allow/Suppress HTML tags in content
      n        Keep/discard name
      l        long file name Acceptable/truncate
      e ERROR  Output error messages to ERROR
               instead of STD_ERR
      q        Quiet mode


merg.c Main program module
This file contains the main() body of the program. Options are
parsed, then passed to the template parser and content parser
(ParseTemplate and ParseContent, respectively). An error pipe
is set, and also passed to the other functions.
*/

#include "merg.h"

static FILE *errpipe = NULL;

int main(int argc, char **argv)
{
	TOKENSTREAM *template;
	char c;
	int retval=0, flags=0;
	
	errpipe = stderr;
	
	while (--argc > 0 && (*++argv)[0] == '-')
		while ((c = *++argv[0]))
			switch (c) {
			case 'h':
				flags |= B_HTML;
				break;
			case 'n':
				flags |= B_NAME;
				break;
			case 'l':
				flags |= B_LFN;
				break;
			case 'q':
				flags |= B_QUIET;
				break;
			case 'd':
				flags |= B_DEBUG;
				break;
			case 'e':
				flags |= B_ERROR;
				break;
			case 's':
				flags |= B_SIMUL;
				break;
			case 'v':
				version();
				return 0;
			
			default:
				printf("MERG: unknown option '%c'\n", c);
				argc = 0;
				retval = -1;
				break;
				
			}

	if (flags & B_ERROR){
		errpipe = fopen(*argv, "w");
		argv++;
		argc--;
	}

	if (argc < 2 && !(flags & B_SIMUL)){		/* if there are less than 2 arguments left */
		help();							/* help the user, please                   */
	}
	else {
		if (!(flags & B_QUIET)){
			header();
			printf("Parsing template: %s\n", *argv);
		}
		template=ParseTemplate(*argv, flags);
		if (template==NULL){
			fprintf(errpipe, "Error processing template file. (100)\n");
			retval = 100;
		}
		else{

			argv++;
			while (--argc){
				if (!(flags & B_QUIET))
					printf("Processing file \"%s\" using template...\n", *argv);
				retval=ParseContent(template, *argv, flags, errpipe);

				if (retval == -1)
					fprintf (errpipe, "Error processing \"%s\"!\n", *argv);
				else if (!(flags & B_QUIET))
					printf("Done.\n\n");
					
				argv++;
			}
			FreeStream(template);
			retval = 0;
		}
	}
	
	return retval;
}

void ErrOut (char * msg)
{
	fprintf(errpipe, msg);
	return;
}